import React from 'react';
import ArchiveSettings20Regular from '@ricons/fluent/lib/ArchiveSettings20Regular';
import DataArea24Regular from '@ricons/fluent/lib/DataArea24Regular';
import DocumentEdit24Regular from '@ricons/fluent/lib/DocumentEdit24Regular';
import Glance24Regular from '@ricons/fluent/lib/Glance24Regular';
import Pulse32Regular from '@ricons/fluent/lib/Pulse32Regular';
import Settings32Regular from '@ricons/fluent/lib/Settings32Regular';
import SignOut24Regular from '@ricons/fluent/lib/SignOut24Regular';
import ClipboardDataBar32Regular from '@ricons/fluent/lib/ClipboardDataBar32Regular';
import ContentView32Regular from '@ricons/fluent/lib/ContentView32Regular';
import ArrowSyncCheckmark24Regular from '@ricons/fluent/lib/ArrowSyncCheckmark24Regular';
import People16Regular from '@ricons/fluent/lib/People16Regular';
import Account from "@ricons/fluent/PersonAccounts24Regular"
import Sale from '@ricons/fluent/ShoppingBagTag24Regular'
import 'twin.macro';
import { PrivilegedItemType } from '@/shared/system';
import Permission from '@ricons/fluent/lib/LockClosed12Regular'
import Statement from '@ricons/fluent/lib/FormNew24Regular'
import ReadingManagement from '@ricons/fluent/lib/Board16Filled'
import Refund from '@ricons/fluent/lib/GroupReturn24Regular'
import { ProjectOutlined } from '@ant-design/icons'

const MainMenuItems: PrivilegedItemType[] = [
  {
    label: '概要信息',
    icon: <Glance24Regular tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'glance',
    link: '/',
    any: [0, 1, 2]
  },
  {
    label: '子账号管理',
    icon: <People16Regular tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'son',
    link: '/son-account',
    any: [0]
  },
  {
    label: '设备管理',
    icon: <ProjectOutlined />,
    key: 'equipment',
    all: [0],
    children: [
      { label: '卡管理', key: 'card', link: '/equipment/card', all: [0] },
      { label: '通讯协议管理', key: 'message', link: '/equipment/message', all: [0] },
      { label: '厂家管理', key: 'factory', link: '/equipment/factory', all: [0] },
      { label: '电表设置', key: 'meter-setting', link: '/equipment/meter-setting', all: [0] },
      { label: '电表操作', key: 'meter-operate', link: '/equipment/meter-operate', all: [0] },
    ]
  },
  {
    label: '用户管理',
    icon: <ArchiveSettings20Regular tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'setup',
    all: [0],
    children: [
      { label: '园区管理', key: 'setup-park', link: '/park/management', all: [0] },
      { label: '建筑管理', key: 'building', link: '/park/building', all: [0] },
      { label: '商户管理', key: 'setup-tenement', link: '/park/tenement', all: [0] },
      { label: '园区表计管理', key: 'setup-kv04', link: '/park/04kv', all: [0] },
      { label: '电表箱管理', key: 'meter-box', link: '/park/meter-box', all: [0] },
      { label: '表计分摊管理', key: 'setup-pooled', link: '/park/pooled', all: [0] }
    ]
  },
  {
    label: "抄表管理", icon: <ReadingManagement tw="w-4 h-4" onPointerEnterCapture={undefined}
                                                onPointerLeaveCapture={undefined}/>, key: 'readingManagement', all: [0], children: [
      { label: '抄表记录', icon: <ClipboardDataBar32Regular tw="w-4 h-4" onPointerEnterCapture={undefined}
                                                            onPointerLeaveCapture={undefined} />, key: 'reading', link: '/reading', all: [0] },
      { label: '退补电量', icon: <Refund tw="w-4 h-4" onPointerEnterCapture={undefined}
                                         onPointerLeaveCapture={undefined} />, key: 'refund', link: '/refund', all: [0] },
    ]
  },
  {
    label: '售电管理',
    icon: <Sale tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'electric',
    any: [0,],
    children: [
      { label: '商户充值', key: 'electric-recharge', link: '/electric/recharge', any: [0] },
      { label: '商户冲正', key: 'electric-reversal', link: '/electric/reversal', any: [0] },
      { label: '商户退费', key: 'electric-return', link: '/electric/return', all: [0] }
    ]
  },
  // { label: '商户充值', icon: <Payment28Regular tw="w-4 h-4" />, key: 'charge', link: '/charge', all: [0] },
  {
    label: '电费核算',
    icon: <DocumentEdit24Regular tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'calculate',
    link: '/calculate/list',
    all: [0]
  },
  {
    label: '企业电费核算',
    icon: <DocumentEdit24Regular tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'calculate-all',
    link: '/calculate/list-all',
    all: [2]
  },
  {
    label: '历史电费核算',
    icon: <DataArea24Regular tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'publicity',
    any: [0, 1, 2],
    children: [
      { label: '往期电费核算检索', key: 'publicity-history', link: '/publicity/retrieval', any: [0, 1, 2] },
      { label: '电费核算撤回审核', key: 'publicity-audit', link: '/publicity/audit', all: [2] }
    ]
  },
  {
    label: '账务管理',
    icon: <Account tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'accounting',
    any: [0,],
    children: [
      { label: '账务记录', key: 'accountingRecord', link: '/accounting/record', any: [0] },
      { label: '账务余额查询', key: 'accountingBalance', link: '/accounting/balance', any: [0] },
      { label: '余额导入', key: 'balanceExport', link: '/accounting/balanceExport', any: [0] },
      // { label: '结算记录检索', key: 'accountingFinish', link: '/accounting/finish', all: [0] }
    ]
  },

  { label: '发票管理', icon: <ContentView32Regular tw="w-4 h-4" onPointerEnterCapture={undefined}
                                                   onPointerLeaveCapture={undefined} />, key: 'invoice', all: [0],children: [
    { label: '发票开具', key: 'invoice-notyet',  link: '/invoice/notyet', any: [0]  },
    { label: '已开发票', key: 'invoice-already', link: '/invoice/already', any: [0]  },
  ] },
  {
    label: '同步管理',
    icon: <ArrowSyncCheckmark24Regular tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'sync',
    any: [0],
    children: [
      { label: '近期同步任务状态', key: 'syncStatus', link: '/sync/status', any: [0, 2] },
      { label: '同步设置', key: 'syncSetting', link: '/sync/setting', all: [0, 2] }
    ]
  },
  {
    label: "流程设置",
    icon: <Settings32Regular tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'flow',
    link: '/flow',
    any: [0],
  },
  {
    label: "报表查询",
    icon: <Statement tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'statement',
    link: '/statement',
    any: [0],
  },
  {
    label: "日志查询",
    icon: <Statement tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'log',
    link: '/log',
    any: [0],
  },
  {
    label: '系统管理',
    icon: <Settings32Regular tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'setting',
    all: [2],
    children: [
      { label: '系统账号管理', key: 'setting-accounts', link: '/account/management', all: [2] },
      { label: '管理单位开户', key: 'setting-openAccount', link: '/account/open', all: [2] },
      { label: '服务期限管理', key: 'setting-charge', link: '/account/charge', all: [2] }
    ]
  },
  {
    label: '天神模式',
    icon: <Pulse32Regular tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'godMode',
    specific: '000',
    children: [
      { label: '用户管理', key: 'gmUsers', link: '/god/user', specific: '000' },
      { label: '园区管理', key: 'gmParks', link: '/god/park', specific: '000' },
      { label: '报表管理', key: 'gmReport', link: '/god/report', specific: '000' },
      {
        key: 'gmSetup',
        specific: '000',
        label: '物业信息管理',
        children: [
          { label: '商户管理', key: 'gmReport-tenement', link: '/god/specific/tenement', specific: '000' },
          { label: '园区表计管理', key: 'gmReport-kv04', link: '/god/specific/04kv', specific: '000' },
          { label: '抄表记录', key: 'gmReport-reading', link: '/god/specific/reading', specific: '000' }
        ]
      }
    ]
  },
  {
    label: '权限设置',
    icon: <Permission tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'permission',
    any: [0],
    link: '/permission'
  },
  {
    label: '退出系统',
    icon: <SignOut24Regular tw="w-4 h-4" onPointerEnterCapture={undefined} onPointerLeaveCapture={undefined} />,
    key: 'quit',
    any: [0, 1, 2],
    link: '/logout'
  }
];


export default MainMenuItems;
