import { SyncAction, SyncParamAction } from '@/shared/foundation';
import { createStoreHook } from './store_creator';
import {ParkInfo} from "@/shared/model-park";

/**
 * 当前登录的用户信息以及会话信息状态存储类型。
 * ! 注意大部分用户信息已经转移到LocalStorage中存储，这里只保存一些辅助性的无关用户登录状态的内容。
 */

type Actions = {
  /**
   * 登出当前用户，重置整个用户状态记录。
   */
  clear: SyncAction;
  /**
   * 处理当前用户登录成功的请求，缓存用户信息。
   */
  setPark: SyncParamAction<ParkInfo>;
};

interface InitState {
  park?: ParkInfo
}

const initialParkState: InitState = {
  park: undefined
};

export const useParkStore = createStoreHook<InitState & Actions>(
  set => ({
    ...initialParkState,
    clear: () =>
      set(st => {
        st.park = null;
      }),
    setPark: response =>
      set(st => {
        st.park = response
      }),

  }),
  { debug: false }
);
